.. Nurex documentation master file, created by
   sphinx-quickstart on Fri Oct 18 20:09:48 2019.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Nurex's documentation
=====================
Nurex is a library for Glauber Model nuclear reaction cross-section calculator. The library is writen in C++ with Python bindings. 

The online web interface can be reached at https://isotopea.com/nurex

Content
-------

.. toctree::
   :maxdepth: 1
   :caption: Installation

   README

.. toctree::
   :maxdepth: 1
   :caption: Usage:
   
   manual
   howto
   tutorial

.. toctree::
   :maxdepth: 1
   :caption: Console App

   nurex_calculator

.. toctree::
   :maxdepth: 1
   :caption: Reference

   api

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
